==> intelliw-1.1.0.tar.gz: intelliw-1.1.0/intelliw/interface/apihandler.py <==
'''
Author: hexu
Date: 2021-10-25 15:20:34
LastEditTime: 2021-10-25 16:55:18
LastEditors: your name
Description: api处理函数
FilePath: /iw-algo-fx/intelliw/interface/apihandler.py
'''
import time
import json
from typing import List
import tornado
import tornado.ioloop
import tornado.web
import tornado.httpserver
import traceback
import intelliw.utils.message as message
from intelliw.core.config import config
from intelliw.utils.util import default_dump
from intelliw.tools.global_val import gl
from urllib.parse import parse_qs
from intelliw.utils.logger import get_logger

logger = get_logger()


class HealthCheckHandler(tornado.web.RequestHandler):
    """健康检查"""

    def post(self):
        self.set_header('Content-Type', 'application/json; charset=UTF-8')
        self.write(str(message.HealthCheckResponse(200, "api", 'ok', "")))

    def get(self):
        self.set_header('Content-Type', 'application/json; charset=UTF-8')
        self.write(str(message.HealthCheckResponse(200, "api", 'ok', "")))


class MainHandler(tornado.web.RequestHandler):
    def initialize(self, func):
        self.func = func
        
    """推理主函数"""
    def post(self):
        infer = gl.get("infer")
        if infer is None:
            self.write(str(message.err_invalid_request))

        self.set_header('Content-Type', 'application/json; charset=UTF-8')
        try:
            content_type = self.request.headers['Content-Type']
            source_body = self.request.body.decode('utf-8')
            if content_type is not None and content_type.startswith('application/x-www-form-urlencoded'):
                data = parse_qs(source_body)  # v1.0 data: dict[str, list[str]]
                for k, v in data.items():  # v1.1 data: dict[str, str]
                    if type(v) == list:
                        data[k] = v[0]
            else:
                r = json.loads(source_body)
                data = r.get('data')
                # extrainfo = r.get('extrainfo') # 空的 extrainfo 定义， 预留
            
            # 根绝算法定义进行推理
            result, emsg = infer.infer(data, self.func)
            if emsg is None:
                self.write(str(message.APIResponse(200, "api", '', result)))
            else:
                self.write(str(message.APIResponse(500, "api", emsg, result)))

        except Exception as e:
            stack_info = traceback.format_exc()
            logger.error("API服务处理推理数据错误 {} stack: {}".format(e, stack_info))

            msg = [
                {
                    'status': 'inferfalied',  # 'start'
                    'inferid': config.INFER_ID,             # ''
                    'instanceid': config.INSTANCE_ID,       # ''
                    'inferTaskStatus': [
                        {
                            "id": config.INFER_ID,
                            "issuccess": False,
                            "starttime": int(time.time() * 1000),
                            "endtime": int(time.time() * 1000),
                            "message": "API服务处理推理数据错误"

                        }
                    ]           # []
                }
            ]
            self.application.reporter.report(message.CommonResponse(500, "inferstatus", "API服务处理推理数据错误 {}".format(
                e), json.dumps(msg, default=default_dump, ensure_ascii=False)))
            self.write(str(message.APIResponse(
                500, "api", "API服务处理推理数据错误 {}".format(e))))

    def get(self):
        self.write(str(message.err_invalid_request))

==> intelliw-1.1.9.tar.gz: intelliw-1.1.9/intelliw/interface/apihandler.py <==
'''
Author: hexu
Date: 2021-10-25 15:20:34
LastEditTime: 2022-03-02 17:14:55
LastEditors: your name
Description: api处理函数
FilePath: /iw-algo-fx/intelliw/interface/apihandler.py
'''
import time
import json
from typing import List
import tornado
import tornado.ioloop
import tornado.web
import tornado.httpserver
import traceback
import intelliw.utils.message as message
from intelliw.config import config
from intelliw.utils.util import default_dump
from intelliw.utils.global_val import gl
from urllib.parse import parse_qs
from intelliw.utils.logger import get_logger

logger = get_logger()


class HealthCheckHandler(tornado.web.RequestHandler):
    """健康检查"""

    def post(self):
        self.set_header('Content-Type', 'application/json; charset=UTF-8')
        self.write(str(message.HealthCheckResponse(200, "api", 'ok', "")))

    def get(self):
        self.set_header('Content-Type', 'application/json; charset=UTF-8')
        self.write(str(message.HealthCheckResponse(200, "api", 'ok', "")))


class MainHandler(tornado.web.RequestHandler):
    def initialize(self, func):
        self.func = func
        
    """推理主函数"""
    def post(self):
        infer = gl.get("infer")
        if infer is None:
            self.write(str(message.err_invalid_request))

        self.set_header('Content-Type', 'application/json; charset=UTF-8')
        try:
            content_type = self.request.headers['Content-Type']
            source_body = self.request.body.decode('utf-8')
            if content_type is not None and content_type.startswith('application/x-www-form-urlencoded'):
                data = parse_qs(source_body) 
            else:
                data = json.loads(source_body)
            
            # 根绝算法定义进行推理
            result, emsg = infer.infer(data, self.func)
            if emsg is None:
                self.write(str(message.APIResponse(200, "api", '', result)))
            else:
                self.write(str(message.APIResponse(500, "api", emsg, result)))

        except Exception as e:
            stack_info = traceback.format_exc()
            logger.error("API服务处理推理数据错误 {} stack: {}".format(e, stack_info))
            msg = [
                {
                    'status': 'inferfalied',  # 'start'
                    'inferid': config.INFER_ID,             # ''
                    'instanceid': config.INSTANCE_ID,       # ''
                    'inferTaskStatus': [
                        {
                            "id": config.INFER_ID,
                            "issuccess": False,
                            "starttime": int(time.time() * 1000),
                            "endtime": int(time.time() * 1000),
                            "message": "API服务处理推理数据错误"

                        }
                    ]           # []
                }
            ]
            self.application.reporter.report(message.CommonResponse(500, "inferstatus", "API服务处理推理数据错误 {}".format(
                e), json.dumps(msg, default=default_dump, ensure_ascii=False)))
            self.write(str(message.APIResponse(
                500, "api", "API服务处理推理数据错误 {}".format(e))))

    def get(self):
        self.write(str(message.err_invalid_request))
